#
# spec file for package gnome-text-editor
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-text-editor
Version:        48.3
Release:        1.1
Summary:        GNOME Text Editor
License:        GPL-3.0-or-later
URL:            https://gitlab.gnome.org/GNOME/gnome-text-editor
Source:         %{name}-%{version}.tar.zst

BuildSystem:    meson
BuildOption:    -Ddevelopment=false

BuildRequires:  fdupes
BuildRequires:  itstool
BuildRequires:  meson >= 0.59.1

# Optional test dependencies
BuildRequires:  desktop-file-utils

%description
Text Editor is a simple text editor that focus on session
management. It works hard to keep track of changes and state even
if you quit the application. You can come back to your work even if
you've never saved it to a file.

%lang_package

%generate_buildrequires
%meson_buildrequires

%install -a
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS README.md
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/applications/org.gnome.TextEditor.desktop
%{_datadir}/dbus-1/services/org.gnome.TextEditor.service
%{_datadir}/glib-2.0/schemas/org.gnome.TextEditor.gschema.xml
%{_datadir}/icons/hicolor/*/*/*.svg
%{_datadir}/metainfo/org.gnome.TextEditor.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Fri May 30 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.3:
  + Fix visual column position in overlay label
  + Defer gtk/gsv initialization to GtkApplication startup so that
    GApplication may determine proper app-id for process without
    relying on systemd/dbus conventions
  + Fix name in properties panel after save-as
  + Updated translations.
* Tue Mar 25 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.2:
  + Break out of recursive Policy-Kit authorization requests from
    user-cancellation.
  + Do not re-display position label as side-effect of auto-save.
  + Updated translations.
* Tue Mar 18 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.1:
  + Fix accessibility properties on search entry.
  + Updated translations.
* Sun Mar 16 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Defaults for markdown no longer imply 80 char right margin and
    it is instead inherted from gsetting defaults.
  + Fallback indentation selection is in preferences now.
  + Updated translations.
* Tue Feb 25 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.rc:
  + Slight UI tweaks to the open button to allow for better
    shrinking of the window to narrow sizes
  + Search bar cancellation bug fixes
  + Fix right-margin-position in preferences not working on some
    distributions
  + Updated translations.
* Tue Feb 18 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Drop erroneous (and unused) appstream-glib BuildRequires: It
  should be AppStream BuildRequires, but it is currently disabled
  upstream, and that one is already pulled in automatically.
* Tue Feb 18 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.beta:
  + More refinement on design updates
  + Search bar moved to bottom of text area
  + Track changes in xdg-portal
  + Updated translations.
* Tue Feb 18 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.alpha:
  + The view menu has been removed in favor of a new properties
    panel based on feedback from users over the past couple of
    years.
  + The indention selection menu has also been removed for the same
    reason.
  + More options in preferences have been exposed.
  + The 'grid' option has been removed from preferences as it has
    had a number of issues. Though if you've enabled it, it will
    continue to be visible to allow turning it off.
  + Opening files with encoding errors will present the option to
    select an encoding from the infobar.
  + Text Editor now uses the new "text" GtkFileDialog APIs from
    GTK. This should allow using portals and thus, Nautilus as a
    file chooser.
  + Document statistics can be updated as you type in the new
    panel.
  + The language selection dialog shows recent languages above
    other languages to make common changes quicker.
  + The position label is now displayed above the editor view when
    the cursor moves for reasons other than typing such as jumping
    by arrow movement or mouse/touch press to move the cursor.
  + Fix alignment/sizing of zoom buttons.
  + A new fullscreen mode similar to Ptyxis/Epiphany.
* Tue Feb 18 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Change spec file to use modern BuildSystem: meson with automatic
  build dependency detection.
- Drop all BuildRequires now autogenerated by meson_buildrequires
  macro.
* Wed Jan 29 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.3:
  + Ensure search context is disposed to help avoid background work
    after a tab has been closed
  + Use weak refs when searching asynchronously to ensure tabs may
    be disposed during background work
  + Close language dialong when Escape is pressed
  + Fix a potentially NULL tooltip
  + Updated translations.
* Fri Nov 22 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Unescaping URIs for tooltips to improve legibility
  + Fix initial-trailing-newline when settings auto-discovery is
    disabled
  + Fix save-as when using admin:// URIs
  + Pin document encoding when loading a file
  + Override extend_selection for multi-mouse-press to avoid some
    slow corner cases in minified JSON files
  + Markup fixes in properties dialog
  + Updated translations.
* Sat Oct 19 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Fix document to default to implicit trailing newlines
  + Improve text wrapping for banners on small form factors
* Sat Sep 14 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Fix focus ring around checkmark in save-changes dialog
  + Updated translations.
* Wed Sep 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Text Editor now uses libspelling for spellchecking
  + Various CSS fixes for transitioning to AdwDialog
  + implicit-trailing-newline is now turned on by default
- Add pkgconfig(libspelling-1) BuildRequires: New dependency.
* Thu Aug 29 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + Various recoloring tweaks to better match platform styling.
  + Improvements to use of AdwDialog.
  + Print operations improvements.
  + Spellcheck improvements including support for use with
    F10/Menu.
  + Prefer wide layout for save-changes-dialog.
- Changes from version 47.alpha:
  + Various UI elements have been ported to new libadwaita features
    so this is a good chance to discover bugs early.
  + A number of papercuts in accordance with the GNOME HIG.
  + Text Editor will try harder to break out of potential CPU
    cyclic issues from GTK forward validation of text buffers. This
    should help reduce CPU usage if/when large files are closed.
  + Various spellcheck improvements.
  + Ensure encoding is propagated when using Save As.
  + More detailed error messages in the error banner.
  + Updated translations.
* Mon May 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.3:
  + Fix a trivial build error when
  - Werror=implicit-function-declaration is specified.
- Changes from version 46.2:
  + Fix an issue with cancellation of closing a page.
  + Try harder to ensure a buffer disposes associated resources
    when the page is closed.
  + Updated translations.
* Thu Apr 11 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Remove DBusActicatable=true from the .desktop file to fix an
    issue where you could spawn Text Editor via D-Bus and not have
    the session restored at startup.
  + AppData fixes.
  + Updated translations.
- Drop data-desktop-disable-DBusActivatable.patch: fixed upstream.
* Tue Mar 26 2024 Elisei Roca <eroca@suse.com>
- Add data-desktop-disable-DBusActivatable.patch: Fixes session
  restore in GNOME 46.
* Sat Mar 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Various performance workarounds have been added to the overview
    map to improve rendering performance and quality with
    fractional scaling.
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Disable editing while document is loading.
  + Discard still-loading documents when saving session.
  + Fix some tab integration issues with libadwaita.
* Tue Feb 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Use AdwAboutDialog.
  + Fix keyboard access to light/dark/follow theme selectors.
  + Use GtkFontDialog instead of deprecated GtkFontChooserDialog.
  + Check for files on disk before restoring drafts to avoid
    displaying deleted files..
  + Performance improvements to the minimap on GTKs new renderer.
  + Avoid draft auto-save file the document is still loading.
  + The language selection dialog is now modal.
  + A new-window action was added to .desktop file for GNOME Shell.
  + Improve support for closing a page while it is still loading.
  + Updated translations.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Make various UI elements conform better to GNOME HIG.
  + Fix etag usage when comparing changes from GFileMonitor.
  + Cancel document loading when tab or window closes. This fixes
    an issue where you could have 100%% CPU doing Pango line
    breaking on extremely large files even after closing a window
    or tab.
  + Improve margin for RTL languages.
  + Updated appdata/metainfo.
  + Fix memory leak in usage of GtkNativeDialog.
  + Work around some broken user configurations for XDG special
    directories.
  + Updated translations.
- Convert to source service for easier updating.
* Mon Oct 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Use proper etag when comparing document for changes after a
    Save As operation occurs.
  + Fix row styling in preferences.
  + Fix memory leak of GtkNativeDialog.
  + Updated translations.
* Sun Sep 17 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.0:
  + Fix tab closing while documents are loading.
  + Shortcuts are removed from tooltips to match GNOME behavior.
    They continue to be available in the shortcuts window.
  + Focus fixes for the language selection dialog making keyboard
    use more accessible.
  + You can now set defaults for "Plain Text" in the language
    dialog.
  + Improved search filtering in the Open popover.
* Thu Aug 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Remove keyboard shortcuts from tooltips.
  + Fix initial focus of language selection dialog.
  + Allow setting "Plain Text" in language selection dialog.
* Sat Jul 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Styling improvements to match recent libadwaita changes
  + Fixes for various settings in per-tab overrides
  + Various Windows build system improvements
  + Style scheme metadata fixes for light/dark mode
  + Updated translations.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Improve spellcheck word boundaries.
  + Various build system improvements.
  + Updated translations.
- Add pkgconfig(cairo) BuildRequires: New explicit dependency.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Style fixes for open popover
  + Fix a small GtkTextTag name leak
  + Ensure a useful size of preferences dialog
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Help documentation updates
  + Improvements to scroll-to-zoom
  + Style scheme updates
  + Additional shortcuts added to help overlay
  + Updated translations.
* Fri Feb 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 44.alpha:
  + Various UI improvements across the open popover, menus, status
    pages, search and preferences.
  + Improvements to handling drafts.
  + Restrict feature set when encountering large files.
  + Updated translations.
* Wed Jan 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Sort recent documents by last-visited (opened) time
  + Fix initial state for search bar buttons
  + Don't allow autosave to race against loading documents
  + Disable search entry when recents list is empty
  + Disable highlighting, spellcheck, and brace matching on large
    files
  + Fix scrolling of large lists in "save changes" dialog
  + Fix emphasis style in various style schemes
  + Updated translations.
* Tue Oct  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Don't toggle editability during (auto)save operations as they
    can break input methods and cause input stalls.
  + Fix ctrl+home/end keyboard shortcut usage.
  + Spellcheck improvements.
  + Provide full document paths in tab tooltips.
  + Fix bugreport_url in about dialog.
  + Use stdout for --version output.
  + Documentation updates.
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + The --version command line option now includes copyright and
    additional version information.
  + Performance improvements to the Open popover list along with
    tooltips to display the full filename.
  + The window title now contains an appropriate tooltip.
  + Path expanding/collapsing is ignored on Windows.
  + Do not do document portal checks.
  + Text Editor will always restore session state when enabled,
    fixing some unexpected behavior in previous releases.
  + Reload documents after using "Open as Administrator" using
    admin:// GVFS protocol.
  + Appdata updates.
  + Updated translations.
* Fri Aug 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.alpha1:
  + Many performance improvements during loading of documents.
  + libeditorconfig (editorconfig-core-c) is now required instead
    of the in-tree copy. This ensures that only PCRE2 is needed.
  + Avoid editable/focusable pages while loading document so that
    a11y peers are not spammed with updates.
  + UI recoloring improvements.
  + Fix horizontal two-finger non-kinetic scrolling.
  + Desktop integration improvements.
  + Updated translations.
- Add pkgconfig(editorconfig) BuildRequires: new depdency.
- Drop pkgconfig(libpcre) BuildRequires: No longer needed.
* Mon Jul 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Text Editor has been updated to use new dialogs from libadwaita
    such as the message about dialogs.
  + Translation improvements.
  + Support for opening local and remove STDIN streams.
  + Suggest new filenames based on current syntax language.
  + Maximized window state is now persisted across sessions.
  + Spellchecking improvements.
  + The modified bit is dropped from draft-only documents when
    discarding to prevent re-opening on next launch.
  + Text Editor now knows if the previous session crashed.
  + A new --version command line argument.
  + Improvements to --new-window command line argument.
  + Window title is fixed when last document is closed.
- Add explict pkgconfig(libpcre) BuildRequires: Needed after GLibs
  port to libpcre2.
* Mon Jun 13 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + Fix a crash at shutdown after saving state. This didn't cause
    any data loss, but could be annoying.
  + Spellcheck underline fixes for various languages.
  + Various robustness fixes for GTK 4.
  + Fixes for inconsistent line-endings.
  + Updated translations.
* Fri Apr 22 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 42.1:
  + Improved preference dialog styling for libadwaita.
  + Build system fixes.
  + Fix icons for zoom controls.
  + Fix titles in save-changes dialog.
  + Updated translations.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc1:
  + CSS styling tweaks.
  + The enchant spellcheck backend will now ignore dictionaries
    which fail to provide a name which can be displayed to the
    user. This so far has only been seen on macOS but may affect
    other platforms.
  + Updated application metadata and screenshots.
  + Updated translations.
* Wed Feb 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta.1:
  + This is our first Beta release as we progress towards GNOME 42.
    A number of bug fixes have landed since 42.alpha2 and we
    encourage your further testing to make 42 a great reveal!
  + Many CSS integration improvements including recoloring
  + Text Editor will now locate style schemes in additional search
    paths
  + Fixes to search bar positioning and focus-in state
  + You can now tweak many per-document settings using the context
    menu within the page which can help users determine what
    settings were/are global from the view menu vs how they were
    overriden by automatic settings discovery (which can be
    disabled in preferences).
  + Smart-Home-End behavior is now enabled in "before" mode
  + New command line options have been added
  + Build fixes for macOS
  + We now advertise the GTK version we require propertly for
    line-height
  + Improvements to titles/subtitles to reflect various document
    capabilities
  + A new style scheme has been added for printing which is used
    automatically until we have further settings in
    GtkPrintOperation via Flatpak portals.
  + More strict checks in B+Tree code for spell checking. If you
    find any assertions, please do tell us!
  + Propertly use AdwApplication base class
  + Improvements to failure paths when access to underlying GFile
    or GFileInfo fails to provide reasonable information.
  + Spellcheck settings are now persisted across sessions using
    extended attributes.
  + The buffer monitor is now disabled when a buffer fails to load
  + The default style scheme is now set to Adwaita propertly
  + Search now draws various bubbles around the matches to make
    them easier to differentiate from the background text.
  + Updated translations.
* Sat Jan  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add appstream-glib and desktop-file-utils BuildRequires: New
  dependencies, and add check section and run meson_test macro.
- Add fdupes BuildRequires and macro, remove duplicates.
* Fri Jan  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha2:
  + Mnemonics for the primary menu have be updated to reduce
    duplicates.
  + Paths are now properly expanded/collapsed for `wordexp()` when
    directories with spaces are used.
  + A new document properties dialog has been added to get
    information about the document such as number of words,
    characters, and lines.
  + Regex search from the search bar works again.
  + Spellchecking will now use the `def:misspelled-word` style from
    the GtkSourceStyleScheme when available, allowing schemes to
    override styling.
  + Fix the default style scheme to be Adwaita in gsettings.
  + You can now navigate and select style schemes with the keyboard
    in the Preferences dialog.
  + Always show the current style scheme in Preferences.
  + Style schemes in Preferences are now sorted in lexicographic
    form along with the presence of an alternate light/dark style.
  + The open popover empty state design has been improved.
  + Track monospace-font-name from desktop preferences.
  + Improve recoloring for some style schemes with metadata
    overrides.
  + Various macOS build and runtime fixes.
  + Add light and dark schemes for both Builder and Peninsula.
  + You can now restore closed pages with Ctrl+Shift+t.
  + Improve printing support for various fonts, sizing, margins,
    and more.
  + Prune discard drafts when cleaning up session.
  + CSS fixes for integrating with libadwaita and GtkSourceView.
  + Various Vim emulation improvements.
  + Text Editor will now prefer "python3" over "python2" when a
    documents content-type matches `text/x-python`, as that is
    overwhelmingly what is found in files today.
  + When windows are restored, they will no longer restore empty
    drafts, even if they were modified previously (added text then
    undo/deleted).
  + The about dialog show now include proper git commit hashes for
    development builds (`meson configure -Ddevelopment=true`) to
    aid in users and distributions submitting helpful bug reports.
  + Updated translations.
* Wed Jan  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha1:
  + Use libadwaita for access to desktop light/dark modes.
  + New interface to jump to a given line number.
  + New keyboard shortcut for delete-current-line, jump-to-line,
    select-current-line, zooming, and preferences.
  + The open popover no longer displays document mtimes, but they
    are used for sorting results.
  + Tab menus are fixed within the document editor.
  + Tabs may now be dragged into new windows.
  + DnD of multiple files into the editor has been restored.
  + Text Editor can no differntiate between indentation and tab
    size.
  + Application startup has been vastly improved.
  + The session manager now truncates the number of bookmarks to
    100.
  + Numerous crash and bug fixes.
  + Guess a reasonable filename for Save As dialog.
  + Deleted text is copied into the primary clipboard when using
    the delete-lines command.
  + A new custom GMenuModel is used for spelling corrections to
    allow for faster updates of menus.
  + Zoom with keybindings and scroll-wheell is now supported.
  + Text Editor will try to discover if style schemes are light or
    dark and only show them when appropriate in preferences.
  + Menus have been significantly tweaked based on usage and
    feedback.
  + Text Editor can no follow the system dark-mode preference.
  + Ensure window is raised when a document is reopened, possibly
    through an external application such as Nautilus.
  + Overview map style improvements.
  + Improved keyboard navigation to and from the open popover.
  + Text Editor will now restyle it's windows based on the selected
    GtkSourceStyleScheme.
  + A new gsetting for how to draw whitespace has been added.
  + A new gestting to disable window restyling has been added.
  + Text Editor now has a Vim emulation layer that may be enabled
    using the org.gnome.TextEditor keybindings gsetting.
  + A statusbar has been added when the Vim emulation is in use
    only.
  + A new and improved preferences dialog which supports previewing
    the preferences changes without leaving the dialog.
  + Search and Replace has been improved and restyled.
  + A new preference to enable restoring the session at startup was
    added.
  + A new preference to enable automatically discovering file
    settings using modelines, editorconfig, and more has been
    added.
  + Improved font styling within the application.
  + Performance and style improvements to the spell checking
    engine.
  + Fixed navigation using Up/Down from search bar.
  + Disabled use of DBusActivatable=true in .desktop file due to
    breakage with opening command line arguments without the
    desktop portal.
  + Improvements to accessibility labels.
  + Updated translations.
* Wed Oct  6 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Improved styling.
  + Give access to --filesystem=host in Flatpak until we have an
    improved document portal story.
  + Raise editor window when raising a page due to opening by an
    external program.
  + Fix keyboard navigation with arrows in search entry.
  + Fix reordering of editor pages with the keyboard.
  + Updated translations.
- Add itstool BuildRequires: New dependency.
* Fri Sep  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Updated translations.
* Mon Aug 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 41.beta1.
